Package: StatescopeR
Type: Package
Title: StatescopeR framework for discovery of cell states from cell
        type-specific gene expression profiles inferred from bulk mRNA
        profiles
Version: 0.99.36
Authors@R: c(
    person(given = "Mischa", family = "Steketee", role = c("aut", "cre"),
             email = "m.f.b.steketee@amsterdamumc.nl",
             comment = c(ORCID = "0000-0001-7138-7554")),
    person(given = "Bauke", family = "Ylstra", role = "ths",
             email = "b.ylstra@amsterdamumc.nl",
             comment = c(ORCID = "0000-0001-9479-3010")),
    person(given = "Yongsoo", family = "Kim", role = "ths",
             email = "yo.kim@amsterdamumc.nl",
             comment = c(ORCID = "0000-0002-2995-2131")),         
    person(given = 'KWF Kankerbestrijding',
                    role = 'fnd'))
Depends: R (>= 4.6.0)
Imports: S4Vectors, SummarizedExperiment, reticulate, methods,
        SingleCellExperiment, matrixStats, scran, basilisk, Matrix,
        ComplexHeatmap, ggplot2, cowplot, utils
Suggests: BiocStyle, knitr, RefManageR, rmarkdown, sessioninfo,
        scRNAseq, scuttle, testthat
Description: StatescopeR is an R wrapper around Statescope, a computational framework designed to discover cell states from cell type-specific gene expression profiles inferred from bulk RNA profiles.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
StagedInstall: no
biocViews: GeneExpression, RNASeq, SingleCell, Bayesian,
        Transcriptomics, Software
URL: https://github.com/tgac-vumc/StatescopeR
BugReports: https://github.com/tgac-vumc/StatescopeR/issues
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/StatescopeR
git_branch: devel
git_last_commit: 9120937
git_last_commit_date: 2026-04-08
Repository: Bioconductor 3.23
Date/Publication: 2026-04-08
NeedsCompilation: no
Packaged: 2026-04-09 00:47:43 UTC; biocbuild
Author: Mischa Steketee [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7138-7554>),
  Bauke Ylstra [ths] (ORCID: <https://orcid.org/0000-0001-9479-3010>),
  Yongsoo Kim [ths] (ORCID: <https://orcid.org/0000-0002-2995-2131>),
  KWF Kankerbestrijding [fnd]
Maintainer: Mischa Steketee <m.f.b.steketee@amsterdamumc.nl>
