# Generated by roxygen2: do not edit by hand

export(BLADE_deconvolution)
export(Refinement)
export(StateDiscovery)
export(barplot_stateloadings)
export(create_signature)
export(fetch_signature)
export(fraction_eval)
export(fraction_heatmap)
export(gather_true_fractions)
export(select_genes)
import(ComplexHeatmap)
import(basilisk)
import(ggplot2)
import(reticulate)
import(scran)
importFrom(Matrix,rowMeans)
importFrom(Matrix,rowSums)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,SimpleList)
importFrom(S4Vectors,metadata)
importFrom(SingleCellExperiment,"logcounts<-")
importFrom(SingleCellExperiment,colData)
importFrom(SingleCellExperiment,logcounts)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assay)
importFrom(cowplot,plot_grid)
importFrom(matrixStats,rowSds)
importFrom(matrixStats,rowVars)
importFrom(methods,is)
importFrom(methods,new)
importFrom(stats,cor)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,read.table)
