% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_functions.R
\name{barplot_stateloadings}
\alias{barplot_stateloadings}
\title{Create a barplot of top stateloadings}
\usage{
barplot_stateloadings(Statescope, top_n = 1)
}
\arguments{
\item{Statescope}{SummarizedExperiment object from StateDiscovery}

\item{top_n}{integer selecting how many genes to show per state}
}
\value{
A barplot rendered to the active graphics device
}
\description{
Create a barplot of top stateloadings
}
\examples{
#' ## Load Discovered Statescope object
load(system.file("extdata", "example_Statescope_Discovered.RData",
    package = "StatescopeR"
))

## Plot fraction heatmap
barplot_stateloadings(Statescope, top_n = 1)

}
