% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_functions.R
\name{fraction_heatmap}
\alias{fraction_heatmap}
\title{Create a heatmap of the estimated fractions}
\usage{
fraction_heatmap(Statescope, ...)
}
\arguments{
\item{Statescope}{SummarizedExperiment object from BLADE_deconvolution}

\item{...}{other parameters to pass to  [ComplexHeatmap::Heatmap()]}
}
\value{
A heatmap rendered to the active graphics device
}
\description{
Create a heatmap of the estimated fractions
}
\examples{
## Load Deconvolved Statescope object
load(system.file("extdata", "example_Statescope_Deconvolved.RData",
    package = "StatescopeR"
))

## Plot fraction heatmap
fraction_heatmap(Statescope)

}
