% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/basilisk.R
\docType{data}
\name{statescope}
\alias{statescope}
\title{Python environments}
\format{
An object of class \code{BasiliskEnvironment} of length 1.
}
\usage{
statescope
}
\description{
Python environments
}
\keyword{datasets}
